@@ -1,14 +1,80 @@
 from click import BadParameter
+import re
 import typer
-from typing import Tuple, List
+from typing import Tuple, List, Dict, Optional
 from pathlib import Path
 from dovado_rtl.doc_parsing import get_directives, get_directives_paragraph
 from dovado_rtl.src_parsing import SourceParser
 from dovado_rtl.vivado_interaction import get_parts
 from dovado_rtl.antlr.hdl_representation import PortDirectionEnum
+from dovado_rtl.simple_types import Metric
 from dovado_rtl.enums import RegressionModel
 
 
+def parse_comma_separated_list(
+    regexp_element: str, to_parse: str
+) -> Optional[List[str]]:
+    return (
+        None
+        if not re.fullmatch(
+            "^("
+            + regexp_element
+            + ")"
+            + "(([ \t]*,[ \t]*)("
+            + regexp_element
+            + "))*$",
+            to_parse,
+        )
+        else [i for i in re.sub(r"[ \t]*", "", to_parse).split(",")]
+    )
+
+
+def ask_utilization_metrics(
+    util_indices: Dict[str, List[str]]
+) -> List[Metric]:
+
+    info_prompt = "Percentage Utilisation indices available:\n"
+    i = 0
+    counter_dict = {}
+    for section in util_indices.keys():
+        info_prompt += section + "\n"
+        for util_metric in util_indices[section]:
+            i = i + 1
+            counter_dict[i] = Metric(
+                utilisation=(section, util_metric), is_frequency=False
+            )
+            info_prompt += "\t(" + str(i) + ") " + util_metric + "\n"
+
+    typer.echo(info_prompt)
+    while True:
+        user_input = typer.prompt(
+            "Enter a comma-separated list of percentage "
+            + "indices to optimize, input -1 to select frequency"
+        )
+        try:
+            parsed_list = [
+                int(i)
+                for i in parse_comma_separated_list(r"[-+]?\d+", user_input)
+            ]
+            if parsed_list and max([i for i in parsed_list if i > 0]) < len(
+                counter_dict
+            ):
+                out: List[Metric] = [
+                    counter_dict[i] for i in {i for i in parsed_list if i >= 0}
+                ]
+                return (
+                    (out + [Metric(None, True)])
+                    if (-1 in parsed_list)
+                    else out
+                )
+        except Exception as e:
+            print(e)
+            print(
+                "Invalid input, please enter"
+                + " a comma separated list of integer numbers"
+            )
+
+
 def validate_nearest_distance(value: int) -> int:
     if value < 0:
         raise typer.BadParameter(
